@@ -300,7 +300,7 @@ static ssize_t reccompile(META *m, IFACE *ifaces, TEXT *source,
 			  int req_ctx, META_ITEM *ctx_item, int *ret_ctx)
 #endif
 {
-	char *s, c;
+	signed char *s, c;
 	INSN *o, *saved_o;
 	ssize_t l, ret;
 	int context, n;
