@@ -47,6 +47,7 @@ struct {
 	{ OP_PUSHSTR, "PUSHSTR" },
 	{ OP_PUSHAV, "PUSHAVREF" },
 	{ OP_POP, "POP" },
+
 	{ OP_NEG, "NEG" },
 	{ OP_NOT, "NOT" },
 	{ OP_MUL, "MUL" },
@@ -66,6 +67,7 @@ struct {
 	{ OP_LT, "LT" },
 	{ OP_EQ, "EQ" },
 	{ OP_NE, "NE" },
+
 	{ OP_BF, "BF" },
 	{ OP_AF, "AF" },
 	{ OP_BL, "BL" },
@@ -76,35 +78,42 @@ struct {
 	{ OP_HEX, "HEX" },
 	{ OP_XORSTR, "XORSTR" },
 	{ OP_CONCAT, "CONCAT" },
+
 	{ OP_GESTR, "GESTR" },
 	{ OP_LESTR, "LESTR" },
 	{ OP_GTSTR, "GTSTR" },
 	{ OP_LTSTR, "LTSTR" },
 	{ OP_EQSTR, "EQSTR" },
 	{ OP_NESTR, "NESTR" },
-	{ OP_ORD2RAW, "ORD2RAW" },
-	{ OP_ORD2DEC, "ORD2DEC" },
-	{ OP_ORD2HEX, "ORD2HEX" },
-	{ OP_ORD2DQ, "ORD2DQ" },
-	{ OP_ORD2YMD, "ORD2YMD" },
-	{ OP_ORD2HMS, "ORD2HMS" },
-	{ OP_ORD2YMDHMS, "ORD2YMDHMS" },
-	{ OP_ORD2DFMT, "ORD2DFMT" },
-	{ OP_DEC2ORD, "DEC2ORD" },
-	{ OP_HEX2ORD, "HEX2ORD" },
-	{ OP_DQ2ORD, "DQ2ORD" },
-	{ OP_YMD2ORD, "YMD2ORD" },
-	{ OP_HMS2ORD, "HMS2ORD" },
-	{ OP_YMDHMS2ORD, "YMDHMS2ORD" },
+
+	{ OP_ORD2OCTSTR, "ORD2OCTSTR" },
+	{ OP_ORD2DECSTR, "ORD2DECSTR" },
+	{ OP_ORD2HEXSTR, "ORD2HEXSTR" },
+	{ OP_ORD2RAWSTR, "ORD2RAWSTR" },
+	{ OP_ORD2IPASTR, "ORD2IPASTR" },
+	{ OP_ORD2DATSTR, "ORD2DATSTR" },
+	{ OP_ORD2DFMSTR, "ORD2DFMSTR" },
+
+	{ OP_OCTSTR2ORD, "OCTSTR2ORD" },
+	{ OP_DECSTR2ORD, "DECSTR2ORD" },
+	{ OP_HEXSTR2ORD, "HEXSTR2ORD" },
+	{ OP_RAWSTR2ORD, "RAWSTR2ORD" },
+	{ OP_IPASTR2ORD, "IPASTR2ORD" },
+	{ OP_DATSTR2ORD, "DATSTR2ORD" },
+	{ OP_INTSTR2ORD, "INTSTR2ORD" },
+
 	{ OP_NO, "NO" },
 	{ OP_JMPZ, "JMPZ" },
 	{ OP_JMPNZ, "JMPNZ" },
+
 	{ OP_ADDAV, "ADDAV" },
 	{ OP_REPLACEAV, "REPLACEAV" },
 	{ OP_DELAV, "DELAV" },
 	{ OP_DELALLAV, "DELALLAV" },
 	{ OP_MOVEALLAV, "MOVEALLAV" },
+
 	{ OP_CALLIFACE, "CALLIFACE" },
+
 	{ -1, "???" }};			/* Must not be included in OPCCNT */
 
 
